
/*------------------------------------------------------------------------
    File        : aa-2203-after-01-aa-auto_attachment_setting.p
    Purpose     :

    Syntax      :

    Description : Conversie programma auto attachment

    Author(s)   : jvm
    Created     : Mon Oct 03 10:15:33 CEST 2022
    Notes       :
                  - zet nooit een include in je conversie programma's, deze staan niet in de uitleverset
                    (met uitzondering van system/conversion.conversion_progress.i)
                  - als de database triggers niet persee af hoeven te gaan , disable ze dan

                  - gebruik de procedure 'DisplayProgress' om info/voortgang en tellers te tonen
                  - gebruik de FIELDS optie als je maar weinig velden hoeft te updaten.

                  - OF gebruik het TRANSACTION keyword als je bij de FOR EACH een EXCLUSIVE-LOCK opgeeft
                    zie onderstaand voorbeeld A

                  - OF gebruik een buffer voor de tabel als je de FOR EACH met NO-LOCK leest
                    zie onderstaand voorbeeld B
  ----------------------------------------------------------------------*/

/* ***************************  Definitions  ************************** */

/* Deze standaard include toevoegen aan conversie programmatuur,
   o.a de DisplayProgress procedure en input paramatere naar de
   aanroepende procedure worden hier in gedefineerd.
   Hierdoor wordt de aansluiting naar de update procedure gemaakt.

   Opmerking: Deze include wordt opgenomen in de System/comversion
              directory welke als ongecompileerd bestand.
              Het is de enige include die opgenomen mag worden in
              de conversie programmatuur.
*/
{System/conversion/conversion_progress.i}

/* ********************  Preprocessor Definitions  ******************** */


/* ***************************  Main Block  *************************** */
DEF VAR cProgram                      AS CHAR NO-UNDO.
DEF VAR cAction                       AS CHAR NO-UNDO.
DEF VAR cTable                        AS CHAR NO-UNDO.
DEF VAR iTotal                        AS INT  NO-UNDO.
DEF VAR iDone                         AS INT  NO-UNDO.
DEF VAR iModulo                       AS INT  NO-UNDO.
DEF VAR cProfile                      AS CHAR NO-UNDO.

DEFINE BUFFER b1-aa-control     FOR aa-control.
DEFINE BUFFER b2-aa-control     FOR aa-control.
DEFINE BUFFER b-sp-mail-profile FOR sp-mail-profile.


cProgram =  THIS-PROCEDURE:FILE-NAME.
cAction  = "Convert sp-mail-profile".
iModulo =  100.  /* om de 100 records info tonen */

/* --------------------------------------------------------------
  Disable triggers op de tabel indien dit mogelijk of
  onderzoek de effecten als de triggers aan moeten
  blijven staan
   -------------------------------------------------------------- */
DISABLE TRIGGERS FOR LOAD OF aa-control.


cTable = "aa-control".
cAction = "Convert aa-controls to sp-mail-profile".

/* --------------------------------------------------------------
   Voortgang van de conversie wordt doormiddel van deze fucntie
   afgehandeld
   -------------------------------------------------------------- */
RUN DisplayProgress (cProgram, cAction, cTable    , iTotal     , iDone).

iDone = 0.
RUN DisplayProgress (cProgram, cAction, cTable    , iTotal     , iDone).


FOR EACH b1-aa-control WHERE 
         b1-aa-control.controlcode BEGINS "sp-mail-profile"
         EXCLUSIVE-LOCK :
  cProfile =  b1-aa-control.list.       

  IF NOT CAN-FIND(FIRST sp-mail-profile WHERE sp-mail-profile.profile_code = cProfile)
  THEN DO:
    CREATE b-sp-mail-profile.
    ASSIGN
      b-sp-mail-profile.profile_code = cProfile
      b-sp-mail-profile.des = 'EWS/Office365'
      b-sp-mail-profile.mail_type = 4
      b-sp-mail-profile.server_name = 'https://smtp.office365.com/ews/exchange.asmx'
      b-sp-mail-profile.ind_savecopy = NO 
      .

    FOR EACH b2-aa-control WHERE 
          b2-aa-control.controlcode BEGINS SUBST('sp-mp-&1-', cProfile)
          EXCLUSIVE-LOCK :
      CASE ENTRY(4, b2-aa-control.controlcode, '-') :
        WHEN "client_id"
        THEN b-sp-mail-profile.client_id = b2-aa-control.list.
        WHEN "client_secret"
        THEN b-sp-mail-profile.client_secret = b2-aa-control.list.
        WHEN "tenant_id"
        THEN b-sp-mail-profile.tenant_id = b2-aa-control.list.
      END CASE.  
      DELETE b2-aa-control.
    END.        
    DELETE b1-aa-control.

    RUN SetMailProfileInEmailService(cProfile).

  END.  

  iDone = iDone  + 1.
  IF iDone MODULO iModulo = 0
  THEN RUN DisplayProgress (cProgram, cAction, cTable    , iTotal     , iDone).
          
END.


RUN DisplayProgress (cProgram, cAction, cTable    , iTotal     , iDone).



PROCEDURE SetMailProfileInEmailService :
  DEFINE INPUT PARAMETER pcMailProfile AS CHARACTER NO-UNDO.

  DISABLE TRIGGERS FOR LOAD OF aa-edi-srv-par.
  DEFINE BUFFER b-aa-edi-srv-par FOR aa-edi-srv-par.

  FIND b-aa-edi-srv-par WHERE 
        b-aa-edi-srv-par.service_code = 'EMAIL'
    AND  b-aa-edi-srv-par.par_name = 'ews-profile'
    EXCLUSIVE-LOCK NO-ERROR.
  IF NOT AVAILABLE b-aa-edi-srv-par
  THEN DO:
    CREATE b-aa-edi-srv-par.
    ASSIGN 
    b-aa-edi-srv-par.service_code = 'EMAIL'
    b-aa-edi-srv-par.par_name = 'ews-profile'
    .
  END.
  ASSIGN 
    b-aa-edi-srv-par.par_value = pcMailProfile.
    .

  FIND b-aa-edi-srv-par WHERE 
        b-aa-edi-srv-par.service_code = 'EMAIL'
    AND  b-aa-edi-srv-par.par_name = 'ews-override'
    EXCLUSIVE-LOCK NO-ERROR.
  IF NOT AVAILABLE b-aa-edi-srv-par
  THEN DO:
    CREATE b-aa-edi-srv-par.
    ASSIGN 
    b-aa-edi-srv-par.service_code = 'EMAIL'
    b-aa-edi-srv-par.par_name = 'ews-override'
    .
  END.
  ASSIGN 
    b-aa-edi-srv-par.par_value = 'yes'
    .

  FIND b-aa-edi-srv-par WHERE 
        b-aa-edi-srv-par.service_code = 'EMAIL'
    AND  b-aa-edi-srv-par.par_name = 'pop3version'
    EXCLUSIVE-LOCK NO-ERROR.
  IF NOT AVAILABLE b-aa-edi-srv-par
  THEN DO:
    CREATE b-aa-edi-srv-par.
    ASSIGN 
    b-aa-edi-srv-par.service_code = 'EMAIL'
    b-aa-edi-srv-par.par_name = 'pop3version'
    .
  END.
  ASSIGN 
    b-aa-edi-srv-par.par_value = 'EWS-Office365'
    .


END PROCEDURE.
